PALM-meteo: palmmeteo_stdplugins.wrf_utils.WRFCoordTransform Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
palmmeteo_stdplugins.wrf_utils.WRFCoordTransform Class Reference
Inheritance diagram for palmmeteo_stdplugins.wrf_utils.WRFCoordTransform:
[legend]
Collaboration diagram for palmmeteo_stdplugins.wrf_utils.WRFCoordTransform:
[legend]

## Public Member Functions
| __init__ (self, ncf)
| latlon_to_ji (self, lat, lon)
| ji_to_latlon (self, j, i)
| verify (self, ncf)

## Public Attributes
| latlon_sphere
| lambert_grid
| dx
| dy
| nx
| ny
| i0_x
| j0_y

## Constructor & Destructor Documentation

## ◆ __init__()

palmmeteo_stdplugins.wrf_utils.WRFCoordTransform.__init__ | ( |  | self,
|  |  | ncf
| ) |  |

Reimplemented in palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform.

## Member Function Documentation

## ◆ ji_to_latlon()

palmmeteo_stdplugins.wrf_utils.WRFCoordTransform.ji_to_latlon | ( |  | self,
|  |  | j,
|  |  | i
| ) |  |

## ◆ latlon_to_ji()

palmmeteo_stdplugins.wrf_utils.WRFCoordTransform.latlon_to_ji | ( |  | self,
|  |  | lat,
|  |  | lon
| ) |  |

## ◆ verify()

palmmeteo_stdplugins.wrf_utils.WRFCoordTransform.verify | ( |  | self,
|  |  | ncf
| ) |  |

Reimplemented in palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform.

## Member Data Documentation

## ◆ dx

palmmeteo_stdplugins.wrf_utils.WRFCoordTransform.dx

## ◆ dy

palmmeteo_stdplugins.wrf_utils.WRFCoordTransform.dy

## ◆ i0_x

palmmeteo_stdplugins.wrf_utils.WRFCoordTransform.i0_x

## ◆ j0_y

palmmeteo_stdplugins.wrf_utils.WRFCoordTransform.j0_y

## ◆ lambert_grid

palmmeteo_stdplugins.wrf_utils.WRFCoordTransform.lambert_grid

## ◆ latlon_sphere

palmmeteo_stdplugins.wrf_utils.WRFCoordTransform.latlon_sphere

## ◆ nx

palmmeteo_stdplugins.wrf_utils.WRFCoordTransform.nx

## ◆ ny

palmmeteo_stdplugins.wrf_utils.WRFCoordTransform.ny

The documentation for this class was generated from the following file:

- palmmeteo_stdplugins/wrf_utils.py